#
# spec file for package goreleaser
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           goreleaser
Version:        2.10.2
Release:        1.1
Summary:        CLI tool for release engineering in Go, Rust, Zig and TypeScript
License:        MIT
URL:            https://goreleaser.com/
Source:         goreleaser-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  golang(API) >= 1.24

%description
CLI tool that provides a single command to build, archive, package, sign and publish artifacts.

%prep
%autosetup -D -a 1

%build
%ifnarch ppc64
export GOFLAGS="-buildmode=pie"
%endif
go build

%install
install -D -m 0755 %{name} %{buildroot}%{_bindir}/%{name}

%check
# Tests are currently broken because they require network.
#go test ./...

%files
%doc README.md
%license LICENSE.md
%{_bindir}/%{name}

%changelog
* Tue Jun 10 2025 Felix Niederwanger <felix.niederwanger@suse.de>
- Update to version 2.10.2:
  * docs: improve install.md
  * docs: update
  * fix(cask): conflicts and depends still not quite right
  * docs: update
  * chore: auto-update generated files
  * chore: keep license in the struct for now
  * fix(homebrew_casks): many fixes
  * chore: auto-update generated files
  * chore: auto-update generated files
  * docs: v2.10
  * docs: update
  * chore(deps): update nfpm
  * docs: update
  * feat: mcp server (#5798)
  * chore(deps): bump golang.org/x/tools from 0.33.0 to 0.34.0 (#5811)
  * feat(ko): allow configuration of local domain to allow publishing to other local registries (e.g. kind) (#5809)
  * chore(deps): bump golang.org/x/text from 0.25.0 to 0.26.0 (#5812)
  * ci: rename job
  * chore(deps): bump golang from 1.24.3-alpine to 1.24.4-alpine (#5815)
  * chore(deps): bump golang.org/x/crypto from 0.38.0 to 0.39.0 (#5813)
  * docs: update USERS.md (#5810)
  * fix(dep): update gitlab, fix use of removed function (#5807)
  * docs: update
  * docs: update
  * docs: improvements based on feedback
  * fix: help case
  * docs: improve casks docs and migration guide
  * test: add test for #5783
  * fix(gitlab): use CI_SERVER_VERSION when available (#5783)
  * ci(dagger): failing zig tests (#5806)
  * chore(deps): bump github/codeql-action from 3.28.18 to 3.28.19 (#5805)
  * chore: schema update
  * feat(cask): improve URL config (#5803)
  * chore(deps): bump golang from `ef18ee7` to `b4f875e` (#5801)
  * feat: support addtional url parameters in homebrew cask (#5800)
  * chore(deps): bump mkdocs-rss-plugin from 1.17.2 to 1.17.3 in /www (#5802)
  * chore: update schema
  * fix: unneeded warnings
  * chore(deps): bump mkdocs-rss-plugin from 1.17.1 to 1.17.2 in /www (#5791)
  * ci: snapcraft token
  * chore(deps): bump github.com/slack-go/slack from 0.16.0 to 0.17.0 (#5792)
  * feat: sbom.disable (#5787)
  * ci: fix zig action (#5789)
  * docs: update
  * chore: deprecate more stuff
  * feat: homebrew casks (#5780)
  * chore(deps): bump github.com/google/go-containerregistry from 0.20.4 to 0.20.5 (#5784)
  * chore(deps): bump github.com/goreleaser/nfpm/v2 from 2.42.0 to 2.42.1 (#5782)
  * chore(deps): bump github.com/google/go-containerregistry from 0.20.4-0.20250225234217-098045d5e61f to 0.20.4 (#5781)
  * test: fix sbom test on newer syft versions
  * fix(init): handle CRLF line endings in gitignore (#5775)
  * chore(deps): bump codecov/codecov-action from 5.4.2 to 5.4.3 (#5776)
  * chore(deps): bump github/codeql-action from 3.28.17 to 3.28.18 (#5777)
  * chore(deps): bump anchore/sbom-action from 0.19.0 to 0.20.0 (#5774)
  * chore(deps): bump mkdocs-material from 9.6.13 to 9.6.14 in /www (#5773)
  * fix(bun,deno): duplicated build flags (#5771)
  * feat(nfpm): support rpm.buildhost
  * chore(deps): update go-github to v72
  * docs: update git tag sort option
  * docs: add blog post about packaging and publishing Go binaries on NPM which use GoReleaser as build tool (#5759)
  * chore(deps): bump mkdocs-material from 9.6.12 to 9.6.13 in /www (#5769)
  * chore(deps): bump dependabot/fetch-metadata from 2.3.0 to 2.4.0 (#5770)
  * chore(deps): update ko and nfpm (#5767)
  * docs: update
  * chore(deps): bump dario.cat/mergo from 1.0.1 to 1.0.2 (#5765)
  * chore(deps): bump actions/setup-go from 5.4.0 to 5.5.0 (#5764)
  * chore(deps): bump mlugg/setup-zig from 1 to 2 (#5762)
  * chore(deps): bump golang from 1.24.2-alpine to 1.24.3-alpine (#5761)
  * ci: fix lint (#5757)
  * fix(brew,nix): support txz, tgz, tzst, tar.zst (#5746)
  * chore(deps): bump golang.org/x/tools from 0.32.0 to 0.33.0 (#5752)
  * chore(deps): bump golang.org/x/oauth2 from 0.29.0 to 0.30.0 (#5753)
  * chore(deps): bump golang.org/x/crypto from 0.37.0 to 0.38.0 (#5751)
  * chore(deps): bump golang.org/x/sync from 0.13.0 to 0.14.0 (#5754)
  * chore(deps): bump golangci/golangci-lint-action from 7.0.0 to 8.0.0 (#5750)
  * chore(deps): bump github/codeql-action from 3.28.16 to 3.28.17 (#5749)
  * docs: update
  * docs: update homepage
  * docs: use recommended SPDX SBOM filename in example (#5745)
  * chore: auto-update generated files
  * chore: auto-update generated files
* Thu May 22 2025 Felix Niederwanger <felix.niederwanger@suse.de>
- Fixed _service: Switch revision from main to actual version
* Wed Apr 30 2025 Felix Niederwanger <felix.niederwanger@suse.de>
- Update to version 2.9.0:
  * chore: auto-update generated files
  * chore: auto-update generated files
  * docs: v2.9 release (#5744)
  * docs: update
  * feat: add checksum template function (#5743)
  * chore: revert acidental commit
  * chore: typo
  * docs: improve choco help
  * fix(brew): improve if hardware structures (#5741)
  * docs: fix typo
  * feat: poetry builder (#5734)
  * chore(deps): bump astral-sh/setup-uv from 5 to 6 (#5739)
  * chore(deps): bump anchore/sbom-action from 0.18.0 to 0.19.0 (#5738)
  * chore(deps): bump gitlab.com/gitlab-org/api/client-go from 0.127.0 to 0.128.0 (#5737)
  * chore(deps): bump github/codeql-action from 3.28.15 to 3.28.16 (#5735)
  * docs: fix npm docs
  * chore(deps): bump sigstore/cosign-installer from 3.8.1 to 3.8.2 (#5732)
  * chore(deps): update
  * ci: remove gitleaks configuration
  * docs: update
  * chore(deps): bump mkdocs-material from 9.6.11 to 9.6.12 in /www (#5727)
  * test: update golden files
  * feat(winget): Add additional template values (#5714)
  * chore(deps): bump stefanzweifel/git-auto-commit-action from 5.1.0 to 5.2.0 (#5729)
  * fix: increase default timeout (#5726)
  * fix: group by platform should consider abi if available (#5723)
  * chore(deps): bump codecov/codecov-action from 5.4.0 to 5.4.2 (#5724)
  * fix: small lint issue
  * fix: upx properly handle skips (#5720)
  * fix: upx.Binary not being respected
  * fix: upx dependencies
  * test: improve artifact type tests
  * docs: update
  * chore: lint
  * feat: uv builder (#5652)
  * fix(aur): panic if both aur and aur_sources configured (#5717)
  * fix: sbom jsonschema
  * feat: allow passing sbomDir to KO (#5688)
  * feat: warn about repeated uploadable artifact names (#5713)
  * chore(deps): update go-github
  * docs: fix
  * docs: build and GOMAXPROCS
  * docs: document accepted config filename variants (#5693)
  * chore(deps): bump gocloud.dev from 0.40.0 to 0.41.0 (#5709)
  * chore(deps): bump golang.org/x/tools from 0.31.0 to 0.32.0 (#5711)
  * chore(deps): bump github/codeql-action from 3.28.13 to 3.28.15 (#5710)
  * chore(deps): bump golang.org/x/sync from 0.12.0 to 0.13.0 (#5705)
  * chore(deps): bump github.com/jarcoal/httpmock from 1.3.1 to 1.4.0 (#5707)
  * chore(deps): bump golang.org/x/oauth2 from 0.28.0 to 0.29.0 (#5704)
  * chore(deps): bump golang from 1.24.1-alpine to 1.24.2-alpine (#5703)
  * chore(deps): bump code.gitea.io/sdk/gitea from 0.20.0 to 0.21.0 (#5700)
  * chore(deps): bump github.com/ory/dockertest/v3 from 3.11.0 to 3.12.0 (#5694)
  * chore(deps): bump gitlab.com/gitlab-org/api/client-go from 0.126.0 to 0.127.0 (#5695)
  * chore(deps): bump github.com/distribution/distribution/v3 from 3.0.0-rc.4 to 3.0.0 (#5696)
* Wed Apr  2 2025 Felix Niederwanger <felix.niederwanger@suse.de>
- Update to version 2.8.2:
  * chore(deps): bump mkdocs-material from 9.6.10 to 9.6.11 in /www (#5692)
  * ci: notify discord if generate job fails
  * chore: auto-update generated files
  * ci: add release:watch
  * ci: fix generate
  * fix: do not set extra replaces to nil
  * chore(deps): bump mkdocs-material from 9.6.9 to 9.6.10 in /www (#5691)
  * refactor: improve extra cast errors
  * refactor: ExtraOr, MustExtra (#5685)
  * chore(deps): update go-github
  * fix(winget): update manifest schema to latest (1.10.0)  (#5683)
  * test: simplify tests with usetesting linter (#5684)
  * chore: update
  * fix: lint
  * fix: jsonschema
  * refactor: organize config code a bit better
  * fix: lint issues (2nd pass) (#5681)
  * fix: lint issues (#5678)
  * docs: alert Markdown Tip section (#5677)
  * chore: fix imports
  * chore: fix imports
  * refactor: modernize codebase
  * refactor: replace interface{} with any
  * ci: fix lint
  * ci: update golangci-lint config
  * chore(deps): bump github/codeql-action from 3.28.12 to 3.28.13 (#5676)
  * chore(deps): bump golangci/golangci-lint-action from 6.5.2 to 7.0.0 (#5675)
  * chore(deps): bump github.com/distribution/distribution/v3 from 3.0.0-rc.3 to 3.0.0-rc.4 (#5673)
  * docs: use docker and pip instead of nix (#5672)
  * fix(nix): cleanup, docs updates, test names
  * fix(nix): use nix-hash instead of nix-prefetch-url (#5669)
  * fix(winget): make tags lowercase (#5664)
  * chore(deps): bump github.com/golang-jwt/jwt/v4 from 4.5.1 to 4.5.2 in the go_modules group (#5668)
  * chore(deps): bump github.com/golang-jwt/jwt/v5 from 5.2.1 to 5.2.2 in the go_modules group (#5667)
  * fix(winget): tags: replace spaces with dash
  * fix(winget): better handle publisher name (#5643)
  * docs: move sponsors to navbar (#5661)
  * chore(deps): bump github/codeql-action from 3.28.11 to 3.28.12 (#5660)
  * chore(deps): bump actions/cache from 4.2.2 to 4.2.3 (#5659)
  * chore(deps): bump actions/setup-go from 5.3.0 to 5.4.0 (#5658)
  * chore(deps): bump golangci/golangci-lint-action from 6.5.1 to 6.5.2 (#5657)
  * chore(deps): bump gitlab.com/gitlab-org/api/client-go from 0.125.0 to 0.126.0 (#5656)
  * chore(deps): bump github.com/BurntSushi/toml from 1.4.0 to 1.5.0 (#5655)
  * docs: improve home page
  * docs: remove announcement
  * docs: fix site home
* Thu Mar 27 2025 Felix Niederwanger <felix.niederwanger@suse.de>
- Re-add Jeff Kowalczyk Packaging improvements that somehow got lost:
-  * Remove FIXME from License: clause, upstream does use MIT license
-  * Summary and Description clarify the purpose of this CLI tool
* Mon Mar 17 2025 felix.niederwanger@suse.de
- Update to version 2.8.1:
  * chore(deps): bump docker/login-action from 3.3.0 to 3.4.0 (#5653)
  * perf: improve default gpg path detection (#5651)
  * docs: fix typos in builds/rust
  * docs: readme update (#5650)
  * chore: auto-update generated files
  * chore(deps): bump github.com/charmbracelet/lipgloss from 1.0.0 to 1.1.0 (#5648)
  * chore(deps): bump gitlab.com/gitlab-org/api/client-go from 0.124.0 to 0.125.0 (#5647)
  * docs: install with npm
  * ci: fix npm configuration
  * ci: fix action
  * ci: fix action
  * chore: auto-update generated files
  * ci: improve nightly task
  * docs: fix fury.disable docs
  * ci: fix nightly/snapshot jobs
  * ci: publish to npm (#5641)
  * fix: properly handle deprecation of snaps.builds
  * fix: notify each deprecation only once (#5642)
  * ci(deps): update dagger et al (#5644)
* Thu Mar 13 2025 felix.niederwanger@suse.de
- Update to version 2.8.0:
  * docs: fix typo
  * chore(deps): bump golangci/golangci-lint-action from 6.5.0 to 6.5.1 (#5640)
  * fix: deprecate ExtraOr
  * docs: announce v2.8 (#5639)
  * chore: auto-update generated files
  * ci: fix nightly changelog
  * docs: prepare for v2.8
  * docs: update
  * build: task release check branch and git status
  * docs: fixed typo
  * docs: update
  * ci: cleanup changelog a bit
  * docs: update
  * chore(deps): bump cachix/install-nix-action from 30 to 31 (#5637)
  * fix(log): custom git log format and parsing (#5635)
  * chore(deps): bump github/codeql-action from 3.28.10 to 3.28.11 (#5634)
  * fix(archive): make sure binaries are executable (#5631)
  * docs: update
  * docs: update
  * fix: improve git no tags error
  * chore: update
  * fix: abbrev test
  * feat(changelog): allow to use format when using the git changeloger (#5627)
  * fix: package comment for packagejson (#5629)
  * docs: update
  * chore(deps): bump github.com/charmbracelet/keygen from 0.5.1 to 0.5.3 (#5628)
  * feat(aur,aursources): support install scripts (#5621)
  * chore(deps): bump golang.org/x/oauth2 from 0.27.0 to 0.28.0 (#5623)
  * chore(deps): bump golang.org/x/tools from 0.30.0 to 0.31.0 (#5626)
  * chore(deps): bump golang.org/x/crypto from 0.35.0 to 0.36.0 (#5622)
  * docs: commit_author fields are templateable
  * chore: update schema
  * fix: notarize timeout being typed as string in jsonschema
  * chore(deps): bump golang from 1.24.0-alpine to 1.24.1-alpine (#5614)
  * chore(deps): bump gitlab.com/gitlab-org/api/client-go from 0.123.0 to 0.124.0 (#5609)
  * chore(deps): bump docker/setup-qemu-action from 3.5.0 to 3.6.0 (#5608)
  * chore(deps): bump codecov/codecov-action from 5.3.1 to 5.4.0 (#5601)
  * chore(deps): bump actions/cache from 4.2.1 to 4.2.2 (#5605)
  * chore(deps): bump github.com/goreleaser/nfpm/v2 from 2.41.2 to 2.41.3 (#5606)
  * chore(deps): bump docker/setup-qemu-action from 3.4.0 to 3.5.0 (#5603)
  * chore(deps): bump docker/setup-buildx-action from 3.9.0 to 3.10.0 (#5602)
  * fix(gitlab): use direct asset path (#5598)
  * fix(docker): add config to artifact extra
  * fix(docker): retry manifest push
  * fix(docker): log img digest after push
  * docs: update
  * chore: schema update
  * docs: correct redirect link for the `Name Templates` article (#5599)
  * reafactor(github): use github.Ptr instead of github.String/Bool/etc
  * feat: aurs.disable and aur_sources.disable
  * docs: update changes from builds to ids
  * feat: snaps.builds -> snaps.ids
  * feat: nfpms.builds -> nfpms.ids
  * feat: archive.builds -> archive.ids
  * fix: snapcraft build filters
  * fix: artifact extras.format for archive when binary
  * docs: mention url_template change
  * chore(deps): bump golang.org/x/crypto from 0.33.0 to 0.35.0 (#5587)
  * chore(deps): bump golang.org/x/oauth2 from 0.26.0 to 0.27.0 (#5586)
  * chore(deps): bump github.com/muesli/termenv from 0.15.2 to 0.16.0 (#5588)
  * chore(deps): bump dagger/dagger-for-github from 7.0.6 to 8.0.0 (#5585)
  * chore(deps): bump github.com/go-jose/go-jose/v4 from 4.0.4 to 4.0.5 in the go_modules group (#5584)
  * chore(deps): bump github/codeql-action from 3.28.9 to 3.28.10 (#5582)
  * fix: improve log
  * refactor: improve semerrogroup usage
  * docs: fix htmtest
  * docs: update
  * docs: update
  * docs: fix title
  * docs: update
  * docs: update
  * docs: update
  * docs: update
  * docs: update
  * docs: update
  * docs: update
  * docs: update
  * docs: update
  * feat: kos.disable (#5580)
  * refactor: moving builtarget into builders/golang (#5569)
  * refactor: ko.doBuild
  * chore(deps): bump sigstore/cosign-installer from 3.8.0 to 3.8.1 (#5577)
  * chore(deps): bump github.com/klauspost/compress from 1.17.11 to 1.18.0 (#5573)
  * chore(deps): bump actions/cache from 4.2.0 to 4.2.1 (#5572)
  * fix: typo in manifest.go (#5571)
* Tue Feb 18 2025 Felix Niederwanger <felix.niederwanger@suse.de>
- Kickoff with version 2.7.0
